@@ -279,7 +279,7 @@ async def call_apropriate_function(
                     message_to_send += "\n"
                 if message_to_send != "":
                     mention_req_user = (
-                        f"<a href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}'>Your requested files</a>\n\n"
+                        f"<a href='tg://user?id={update.from_user.id}'>{update.from_user.first_name}</a>'>Your requested files</a>\n\n"
                     )
                     message_to_send = mention_req_user + message_to_send
                     message_to_send = message_to_send + "\n\n" + "#uploads"
